@@ -162,10 +162,10 @@ TEST_DATA = {
             "data": {
                 "Patient Name": "",
                 "Patient ID": "",
-                "Plan Date": "05.09.2019  2:26 PM",
+                "Plan Date": "09/05/2019  2:26 PM",
                 "Plan Name": "1-2 RUL",
-                "Meas Date": "05.09.2019  7:05 PM",
-                "Accepted Date": "05.09.2019  7:15 PM",
+                "Meas Date": "09/05/2019  7:05 PM",
+                "Accepted Date": "09/05/2019  7:15 PM",
                 "Radiation Dev": "TrueBeam1",
                 "Energy": "6 MV, FFF",
                 "Daily Corr": "1.010",
@@ -297,6 +297,34 @@ TEST_DATA = {
                 "Beam Count": 2,
             },
         },
+        "AM/PM in date, month/day swapped": {
+            "path": join(
+                DIRECTORIES["DELTA4_EXAMPLES"],
+                "UChicago",
+                "DCAM_example_9.pdf",
+            ),
+            "data": {
+                "Patient Name": "",
+                "Patient ID": "",
+                "Plan Date": "11/22/2017  11:01 AM",
+                "Plan Name": "D4QA 1-1",
+                "Meas Date": "11/22/2017  3:57 PM",
+                "Radiation Dev": "UC_M120",
+                "Energy": "6 MV",
+                "Daily Corr": "1.053",
+                "Norm Dose": "261 cGy",
+                "Dev": "99.6%",
+                "DTA": "99.6%",
+                "DTA Criteria": "n.a.",
+                "Dose Dev": "0.6%",
+                "Gamma-Index": "99.6%",
+                "Gamma Pass Criteria": "95%",
+                "Gamma Dose Criteria": "3.0%",
+                "Gamma Dist Criteria": "3.0 mm",
+                "Threshold": "10%",
+                "Beam Count": 2,
+            },
+        },
     },
     "sncpatient": {
         "FirstUChicago": {
@@ -431,6 +459,36 @@ TEST_DATA = {
                 "Notes": "19E",
             },
         },
+        "Beaumont-long-patient-name": {
+            "path": join(
+                DIRECTORIES["SNCPATIENT_EXAMPLES"],
+                "Beaumont",
+                "1.pdf",
+            ),
+            "data": {
+                "Patient Name": "ZZZ_RPC, HEAD_AND_NECK",
+                "Patient ID": "51515151",
+                "QA Date": "7/8/2016",
+                "Plan Date": "8/7/2016",
+                "Energy": "0",
+                "Angle": "",
+                "SSD": "867.1",
+                "SDD": "1000.0",
+                "Depth": "132.9",
+                "Dose Type": "Absolute",
+                "Difference (%)": "3.0",
+                "Distance (mm)": "2.0",
+                "Threshold (%)": "10.0",
+                "Meas Uncertainty": "Yes",
+                "Use Global (%)": "Yes",
+                "Summary Type": "Summary (Gamma Analysis)",
+                "Total Points": "453",
+                "Pass": "406",
+                "Fail": "47",
+                "Pass (%)": "89.6",
+                "Notes": "1",
+            },
+        },
     },
     "sncpatient2020": {
         "NorthwesternArcCheck1": {
